@@ -316,6 +316,8 @@ const (
 	ArgAllowList = "allow-list"
 	// ArgDenyList is a list of firewall rules for DENYING traffic to the loadbalancer
 	ArgDenyList = "deny-list"
+	// ArgLoadBalancerType is the type of the load balancer.
+	ArgLoadBalancerType = "type"
 
 	// ArgFirewallName is a name of the firewall.
 	ArgFirewallName = "name"
@@ -363,6 +365,8 @@ const (
 	ArgDatabasePoolMode = "mode"
 	// ArgDatabaseUserMySQLAuthPlugin is a flag for setting the MySQL user auth plugin
 	ArgDatabaseUserMySQLAuthPlugin = "mysql-auth-plugin"
+	// ArgDatabasePrivateConnectionBool determine if the private connection details should be shown
+	ArgDatabasePrivateConnectionBool = "private"
 
 	// ArgPrivateNetworkUUID is the flag for VPC UUID
 	ArgPrivateNetworkUUID = "private-network-uuid"
